==> haskell-critbit-0.2.0.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-F5N69rdA58e7cc7fYvseQS
key: critbit-0.2.0.0-F5N69rdA58e7cc7fYvseQS
license: BSD-3-Clause
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
abi: 1cbf51aa751c6870acd6d957edad3c98
exposed: True
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-F5N69rdA58e7cc7fYvseQS
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
    text-1.2.3.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-critbit-0.2.0.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-LNMNtwjFW5U71GyzASVtI5
key: critbit-0.2.0.0-LNMNtwjFW5U71GyzASVtI5
license: BSD-3-Clause
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
abi: a363a0369a0a53c7321cd988445651de
exposed: True
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
import-dirs: /usr/lib/ghc-8.6.1/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-LNMNtwjFW5U71GyzASVtI5
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    text-1.2.3.1 vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
